@@ -30,7 +30,9 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -41,7 +43,6 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  convertUnknownCategoricalLevelsToNa=False,
                  splitRatio=1.0,
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  ntrees=50,
                  maxDepth=6,
                  minRows=1.0,
@@ -80,8 +81,9 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  skipDrop=0.0,
                  dmatrixType="auto",
                  backend="auto",
-                 gpuId=0,
+                 gpuId=None,
                  interactionConstraints=None,
+                 scalePosWeight=1.0,
                  modelId=None,
                  nfolds=0,
                  keepCrossValidationModels=True,
@@ -102,12 +104,14 @@ class H2OXGBoostClassifier(H2OXGBoost):
                  stoppingMetric="AUTO",
                  stoppingTolerance=0.001,
                  gainsliftBins=-1,
-                 exportCheckpointsDir=None):
+                 exportCheckpointsDir=None,
+                 aucType="AUTO"):
         Initializer.load_sparkling_jar()
         super(H2OXGBoost, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.classification.H2OXGBoostClassifier", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
+        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
