@@ -44,9 +44,8 @@ class H2OAutoMLRegressor(H2OAutoML):
                  splitRatio=1.0,
                  monotoneConstraints={},
                  withStageResults=False,
-                 withDetailedPredictionCol=True,
                  projectName=None,
-                 nfolds=5,
+                 nfolds=-1,
                  balanceClasses=False,
                  classSamplingFactors=None,
                  maxAfterBalanceSize=5.0,
@@ -54,6 +53,11 @@ class H2OAutoMLRegressor(H2OAutoML):
                  keepCrossValidationModels=False,
                  keepCrossValidationFoldAssignment=False,
                  exportCheckpointsDir=None,
+                 distribution="AUTO",
+                 tweediePower=1.5,
+                 quantileAlpha=0.5,
+                 huberAlpha=0.9,
+                 customDistributionFunc=None,
                  labelCol="label",
                  foldCol=None,
                  weightCol=None,
